# - Config file for the ${PROJECT_NAME} package
# It defines the following variables
#  ${PROJECT_NAME}_INCLUDE_DIRS - include directory for ${PROJECT_NAME}
#  ${PROJECT_NAME}_LIBRARIES    - all libraries to link against (warning, may be slower than just specify the used libs)
#  ${PROJECT_NAME}_ALL_FOUND    - set to TRUE if all requested COMPONENTS are specified (see below), false otherwise
#  ${PROJECT_NAME}_MISSING_TOOLKITS - when ${PROJECT_NAME}_ALL_FOUND is FALSE, contains a list of missing toolkits
#  ${PROJECT_NAME}_ALL_BUILT_MODULES - the list of source directories compiled (mostly useful when running swig to generate wrappers)
#
# If COMPONENTS is specified in the find_package() commands, it contains
# a list of toolkit modules which are requested.  For each component,
# ${PROJECT_NAME}_<toolkit>_FOUND is set to TRUE or FALSE.
# Warning: <toolkit> is case-sensitive, for instance TKernel.
# For convenience, ${PROJECT_NAME}_ALL_FOUND is set to TRUE if all
# toolkits are found, otherwise FALSE.  In the latter case,
# ${PROJECT_NAME}_MISSING_TOOLKITS contains the list of missing toolkits.
 
# Tell the user project where to find our headers and libraries
GET_FILENAME_COMPONENT(SELF_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

SET(OCE_INCLUDE_DIRS "${SELF_DIR}/../../../include/oce")
SET(OCE_LIBRARIES "TKernel;TKMath;TKAdvTools;TKG2d;TKG3d;TKGeomBase;TKBRep;TKGeomAlgo;TKTopAlgo;TKPrim;TKBO;TKHLR;TKMesh;TKShHealing;TKXMesh;TKBool;TKFillet;TKFeat;TKOffset;TKService;TKV2d;TKV3d;TKOpenGl;TKMeshVS;TKNIS;TKVoxel;TKCDF;PTKernel;TKLCAF;FWOSPlugin;TKPShape;TKBinL;TKXmlL;TKPLCAF;TKTObj;TKShapeSchema;TKStdLSchema;TKCAF;TKBin;TKXml;TKPCAF;TKBinTObj;TKXmlTObj;TKStdSchema;TKSTL;TKXSBase;TKSTEPBase;TKIGES;TKSTEPAttr;TKSTEP209;TKSTEP;TKVRML;TKXCAF;TKXCAFSchema;TKXmlXCAF;TKBinXCAF;TKXDEIGES;TKXDESTEP;TKDraw;TKTopTest;TKViewerTest;TKXSDRAW;TKDCAF;TKXDEDRAW;TKTObjDRAW;TKQADraw;DRAWEXE")
SET(OCE_ALL_BUILT_MODULES "StdFail;FSD;MMgt;OSD;Plugin;Quantity;Resource;SortTools;Standard;Storage;TColStd;TCollection;TShort;Units;UnitsAPI;IncludeLibrary;Dico;NCollection;Message;math;ElCLib;ElSLib;BSplCLib;BSplSLib;PLib;Precision;GeomAbs;Poly;CSLib;Convert;Bnd;gp;TColgp;TopLoc;Dynamic;Materials;Expr;ExprIntrp;GraphDS;GraphTools;Geom2d;LProp;TColGeom2d;Adaptor2d;Geom2dLProp;Geom2dAdaptor;TopAbs;GProp;Geom;TColGeom;GeomAdaptor;AdvApprox;GeomLProp;Adaptor3d;LProp3d;ProjLib;GeomProjLib;GCPnts;CPnts;Approx;AppParCurves;FEmTool;AppCont;Extrema;IntAna;IntAna2d;GeomConvert;AdvApp2Var;GeomLib;Geom2dConvert;Hermit;BndLib;AppDef;GeomTools;GC;GCE2d;gce;TopoDS;TopExp;TopTools;BRep;BRepLProp;BRepAdaptor;BRepTools;Hatch;GeomInt;IntStart;IntWalk;IntImp;IntCurveSurface;IntSurf;IntPatch;Geom2dInt;IntImpParGen;IntRes2d;IntCurve;TopTrans;Intf;ApproxInt;GccAna;GccEnt;GccInt;GccIter;GccGeo;HatchGen;Geom2dHatch;Law;AppBlend;Plate;GeomPlate;LocalAnalysis;GeomAPI;GeomFill;Geom2dAPI;Geom2dGcc;FairCurve;NLPlate;IntPolyh;TopClass;IntCurvesFace;MAT;MAT2d;Bisector;BRepMAT2d;BRepCheck;BRepBndLib;BRepExtrema;BRepClass;BRepClass3d;BRepLib;BRepGProp;BRepIntCurveSurface;BRepTopAdaptor;BRepBuilderAPI;BRepApprox;BRepPrim;Primitives;BRepSweep;Sweep;BRepPrimAPI;BOPTColStd;BOPTools;BOP;BooleanOperations;IntTools;BRepAlgoAPI;HLRTopoBRep;HLRBRep;HLRAlgo;Intrv;TopBas;TopCnx;Contap;MeshDS;BRepMesh;MeshAlgo;IntPoly;ShapeBuild;ShapeExtend;ShapeConstruct;ShapeCustom;ShapeAnalysis;ShapeFix;ShapeUpgrade;ShapeAlgo;ShapeProcess;ShapeProcessAPI;XBRepMesh;TopOpeBRep;TopOpeBRepDS;TopOpeBRepBuild;TopOpeBRepTool;BRepAlgo;BRepFill;BRepProj;ChFiDS;ChFi2d;ChFi3d;ChFiKPart;Blend;BRepBlend;BlendFunc;BRepFilletAPI;FilletSurf;LocOpe;BRepFeat;BRepOffsetAPI;Draft;BRepOffset;BiTgte;AlienImage;Aspect;CGM;Font;Image;MFT;PS;PlotMgt;SelectBasics;TColQuantity;Viewer;ImageUtility;Xw;V2d;Graphic2d;Select2D;Prs2d;AIS2D;GGraphic2d;V3d;Graphic3d;Visual3d;Select3D;Prs3d;StdPrs;SelectMgr;PrsMgr;AIS;DsgPrs;StdSelect;OpenGl;MeshVS;NIS;Voxel;CDM;PCDM;CDF;UTL;LDOM;DBC;PCollection;PColStd;PMMgt;PShort;PStandard;PTColStd;ObjMgt;TDF;TDataStd;TFunction;TDocStd;AppStdL;FWOSDriver;PBRep;PTopoDS;PGeom;PGeom2d;PPoly;PColgp;PTopLoc;PColPGeom;PColPGeom2d;MgtBRep;MgtGeom;MgtGeom2d;MgtPoly;MgtTopLoc;MgtTopoDS;BinMDF;BinMDataStd;BinMFunction;BinMDocStd;BinObjMgt;BinLDrivers;XmlLDrivers;XmlMDF;XmlMDataStd;XmlMDocStd;XmlMFunction;XmlObjMgt;PDF;PDataStd;PFunction;PDocStd;MDF;MDataStd;MFunction;MDocStd;TObj;ShapeSchema;PCDMShape;StdLSchema;StdLDrivers;TDataXtd;TNaming;TPrsStd;AppStd;BinDrivers;BinMDataXtd;BinMPrsStd;BinMNaming;BinTools;XmlDrivers;XmlMDataXtd;XmlMNaming;XmlMPrsStd;PDataXtd;PNaming;PPrsStd;MDataXtd;MPrsStd;MNaming;BinTObjDrivers;XmlTObjDrivers;StdSchema;StdDrivers;StlMesh;StlAPI;StlTransfer;RWStl;Interface;Transfer;IFGraph;IFSelect;TransferBRep;XSControl;StepData;StepFile;HeaderSection;RWHeaderSection;APIHeaderSection;StepSelect;UnitsMethods;XSAlgo;LibCtl;MoniTool;StepBasic;RWStepBasic;StepRepr;RWStepRepr;StepGeom;RWStepGeom;StepShape;RWStepShape;IGESData;IGESFile;IGESBasic;IGESGraph;IGESGeom;IGESDimen;IGESDraw;IGESSolid;IGESDefs;IGESAppli;IGESConvGeom;IGESSelect;IGESToBRep;GeomToIGES;Geom2dToIGES;BRepToIGES;BRepToIGESBRep;IGESControl;StepVisual;RWStepVisual;StepDimTol;RWStepDimTol;StepElement;StepFEA;RWStepElement;RWStepFEA;StepAP214;RWStepAP214;StepAP203;RWStepAP203;STEPConstruct;STEPEdit;GeomToStep;StepToGeom;StepToTopoDS;TopoDSToStep;STEPControl;STEPSelections;StepAP209;VrmlConverter;VrmlAPI;Vrml;VrmlData;XCAFApp;XCAFDoc;XCAFPrs;MXCAFDoc;PXCAFDoc;XCAFDrivers;XCAFSchema;XmlXCAFDrivers;XmlMXCAFDoc;BinXCAFDrivers;BinMXCAFDoc;IGESCAFControl;STEPCAFControl;Draw;DBRep;DrawTrSurf;TestTopOpeDraw;TestTopOpeTools;TestTopOpe;BRepTest;GeometryTest;HLRTest;MeshTest;GeomliteTest;DrawFairCurve;BOPTest;Viewer2dTest;ViewerTest;SWDRAW;XSDRAW;XSDRAWIGES;XSDRAWSTEP;XSDRAWSTLVRML;DDF;DDocStd;DNaming;DDataStd;DPrsStd;DrawDim;XDEDRAW;TObjDRAW;DebugTools;QABugs;QADNaming;QADraw;QANCollection;QANewBRepNaming;QANewDBRepNaming;QANewModTopOpe")
FILE(GLOB DEBIAN_TARGET_FILES ${SELF_DIR}/OCE*Targets.cmake)
LIST(SORT DEBIAN_TARGET_FILES)
FOREACH(file ${DEBIAN_TARGET_FILES})
	INCLUDE("${file}")
ENDFOREACH(file ${DEBIAN_TARGET_FILES})

SET(OCE_ALL_FOUND true)
IF(OCE_FIND_COMPONENTS)
	FOREACH(toolkit ${OCE_FIND_COMPONENTS})
		IF(TARGET ${toolkit})
			SET(OCE_${toolkit}_FOUND true)
		ELSE(TARGET ${toolkit})
			SET(OCE_ALL_FOUND false)
			SET(OCE_${toolkit}_FOUND false)
			SET(OCE_MISSING_TOOLKITS ${OCE_MISSING_TOOLKITS} ${toolkit})
			IF(OCE_FIND_REQUIRED)
				MESSAGE(FATAL_ERROR "OCE ${toolkit} not available.")
			ENDIF(OCE_FIND_REQUIRED)
		ENDIF(TARGET ${toolkit})
	ENDFOREACH(toolkit ${OCE_FIND_COMPONENTS})
ENDIF(OCE_FIND_COMPONENTS)
